@@ -1,8 +1,8 @@
 package org.gcube.portlets.user.td.expressionwidget.shared.rule;
 
+import java.util.Date;
 
-
-
+import org.gcube.portlets.user.td.gwtservice.shared.rule.description.RuleDescriptionData;
 
 import com.google.gwt.editor.client.Editor.Path;
 import com.sencha.gxt.core.client.ValueProvider;
@@ -11,20 +11,26 @@ import com.sencha.gxt.data.shared.PropertyAccess;
 
 /**
  * 
- * @author giancarlo
- * email: <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
+ * @author giancarlo email: <a
+ *         href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a>
  *
  */
-public interface RuleDescriptionDataProperties  extends PropertyAccess<RuleDescriptionData> {
-	
+public interface RuleDescriptionDataProperties extends
+		PropertyAccess<RuleDescriptionData> {
+
 	@Path("id")
 	ModelKeyProvider<RuleDescriptionData> id();
-	
-	ValueProvider<RuleDescriptionData, String> name();
-	ValueProvider<RuleDescriptionData, String> description();
-	ValueProvider<RuleDescriptionData, String> owner();
-	ValueProvider<RuleDescriptionData, String> readableExpression();
-	
-	
-}
 
+	ValueProvider<RuleDescriptionData, String> name();
+
+	ValueProvider<RuleDescriptionData, String> scopeLabel();
+	
+	ValueProvider<RuleDescriptionData, Date> creationDate();
+
+	ValueProvider<RuleDescriptionData, String> description();
+
+	ValueProvider<RuleDescriptionData, String> ownerLogin();
+
+	ValueProvider<RuleDescriptionData, String> readableExpression();
+
+}
